from setuptools import setup, find_packages

setup(
    name="torch_metrics",
    version="1.0.8",
    description="Metrics for model evaluation in pytorch",
    url="https://github.com/chinokenochkan/torch-metrics",
    author="Chi Nok Enoch Kan @chinokenochkan",
    author_email="kanxx030@gmail.com",
    packages=["torch_metrics"],
)